==> py3-ncclient-0.6.6p2.tgz: lib/python3.8/site-packages/ncclient/operations/__init__.py <==
# Copyright 2009 Shikhar Bhushan
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from ncclient.operations.errors import OperationError, TimeoutExpiredError, MissingCapabilityError
from ncclient.operations.rpc import RPC, RPCReply, RPCError, RaiseMode

# rfc4741 ops

from ncclient.operations.retrieve import Get, GetConfig, GetSchema, GetReply, Dispatch
from ncclient.operations.edit import EditConfig, CopyConfig, DeleteConfig, Validate, Commit, DiscardChanges, CancelCommit
from ncclient.operations.session import CloseSession, KillSession
from ncclient.operations.lock import Lock, Unlock, LockContext
from ncclient.operations.subscribe import CreateSubscription

# others...
from ncclient.operations.flowmon import PoweroffMachine, RebootMachine

__all__ = [
    'RPC',
    'RPCReply',
    'RPCError',
    'RaiseMode',
    'Get',
    'GetConfig',
    'GetSchema',
    'Dispatch',
    'GetReply',
    'EditConfig',
    'CopyConfig',
    'Validate',
    'Commit',
    'DiscardChanges',
    'CancelCommit',
    'DeleteConfig',
    'Lock',
    'Unlock',
    'CreateSubscription',
    'PoweroffMachine',
    'RebootMachine',
]

==> py3-ncclient-0.6.18p0.tgz: lib/python3.12/site-packages/ncclient/operations/__init__.py <==
# Copyright 2009 Shikhar Bhushan
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from ncclient.operations.errors import OperationError, TimeoutExpiredError, MissingCapabilityError
from ncclient.operations.rpc import RPC, RPCReply, RPCError, RaiseMode, GenericRPC

# rfc4741 ops

from ncclient.operations.retrieve import Get, GetConfig, GetSchema, GetReply, Dispatch
from ncclient.operations.edit import EditConfig, CopyConfig, DeleteConfig, Validate, Commit, DiscardChanges, CancelCommit
from ncclient.operations.session import CloseSession, KillSession
from ncclient.operations.lock import Lock, Unlock, LockContext
from ncclient.operations.subscribe import CreateSubscription

# others...
from ncclient.operations.flowmon import PoweroffMachine, RebootMachine

__all__ = [
    'RPC',
    'RPCReply',
    'RPCError',
    'RaiseMode',
    'GenericRPC',
    'Get',
    'GetConfig',
    'GetSchema',
    'Dispatch',
    'GetReply',
    'EditConfig',
    'CopyConfig',
    'Validate',
    'Commit',
    'DiscardChanges',
    'CancelCommit',
    'DeleteConfig',
    'Lock',
    'Unlock',
    'CreateSubscription',
    'PoweroffMachine',
    'RebootMachine',
]
